@@ -33,6 +33,12 @@ parser.add_argument(
     help="Batch size to use in salt",
     default=10
 )
+parser.add_argument(
+    "--batch-wait",
+    type=int,
+    help="Seconds to wait after a minion returns, before sending the command to a new minion",
+    default=10
+)
 parser.add_argument(
     "--salt-target",
     type=str,
